# **Too-yy, designed by yy**

## Installing and Getting started

1. Install

    The easiest way to install.
    
        pip install tool-yy
  
    Or you can clone source code from github.
  
        git clone git@github.com:guaidashu/python3_tool_myself.git

3. Start

    Example

  	    from tool_yy import helper
  	    
  	    if __name__ == "__main__":
            db = helper.init_db("INSOMNIA_MUSIC_DATABASE_CONFIG")


## Usage

None

## FAQ

None

## Running Tests

## Finally Thanks 

Thanks for your support.